/* SPDX-License-Identifier: (GPL-2.0-only OR MIT) */
/*
 * Copyright (C) 2024 Amlogic, Inc. All rights reserved
 */

#ifndef _DT_BINDINGS_AMLOGIC_A5_POWER_H
#define _DT_BINDINGS_AMLOGIC_A5_POWER_H

#define PWRC_A5_NNA_ID			0
#define PWRC_A5_AUDIO_ID		1
#define PWRC_A5_SDIOA_ID		2
#define PWRC_A5_EMMC_ID			3
#define PWRC_A5_USB_COMB_ID		4
#define PWRC_A5_ETH_ID			5
#define PWRC_A5_RSA_ID			6
#define PWRC_A5_AUDIO_PDM_ID		7
#define PWRC_A5_DMC_ID			8
#define PWRC_A5_SYS_WRAP_ID		9
#define PWRC_A5_DSPA_ID			10

#endif
