/*
 * Copyright (C) 2016 Icenowy Zheng <icenowy@aosc.io>
 *
 * SPDX-License-Identifier: (GPL-2.0+ OR MIT)
 */

#ifndef _DT_BINDINGS_RESET_SUN8I_DE2_H_
#define _DT_BINDINGS_RESET_SUN8I_DE2_H_

#define RST_MIXER0	0
#define RST_MIXER1	1
#define RST_WB		2
#define RST_ROT		3

#endif /* _DT_BINDINGS_RESET_SUN8I_DE2_H_ */
