/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Copyright (C) 2021 Daniel Mack
 */

#ifndef __DT_BINDINGS_CS2000CP_CLK_H
#define __DT_BINDINGS_CS2000CP_CLK_H

#define CS2000CP_AUX_OUTPUT_REF_CLK	0
#define CS2000CP_AUX_OUTPUT_CLK_IN	1
#define CS2000CP_AUX_OUTPUT_CLK_OUT	2
#define CS2000CP_AUX_OUTPUT_PLL_LOCK	3

#endif /* __DT_BINDINGS_CS2000CP_CLK_H */
