/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Copyright (c) 2024, Qualcomm Innovation Center, Inc. All rights reserved.
 */

#ifndef _DT_BINDINGS_CLK_QCOM_QCS8300_CAM_CC_H
#define _DT_BINDINGS_CLK_QCOM_QCS8300_CAM_CC_H

#include "qcom,sa8775p-camcc.h"

/* QCS8300 introduces below new clocks compared to SA8775P */

/* CAM_CC clocks */
#define CAM_CC_TITAN_TOP_ACCU_SHIFT_CLK				86

#endif
